<?php
$TRANSLATIONS = array(
"Invalid value supplied for %s" => "Uvedena nesprávná hodnota pro %s",
"Saved" => "Uloženo",
"test email settings" => "otestovat nastavení e-mailu",
"If you received this email, the settings seem to be correct." => "Pokud jste obdrželi tento e-mail, nastavení se zdají být v pořádku.",
"A problem occurred while sending the e-mail. Please revisit your settings." => "Při odesílání e-mailu nastala chyba. Překontrolujte vaše nastavení.",
"Email sent" => "E-mail odeslán",
"You need to set your user email before being able to send test emails." => "Pro možnost odeslání zkušebních e-mailů musíte nejprve nastavit svou e-mailovou adresu.",
"Send mode" => "Mód odesílání",
"Encryption" => "Šifrování",
"Authentication method" => "Metoda ověření",
"Unable to load list from App Store" => "Nelze načíst seznam z App Store",
"Authentication error" => "Chyba přihlášení",
"Your full name has been changed." => "Vaše celé jméno bylo změněno.",
"Unable to change full name" => "Nelze změnit celé jméno",
"Group already exists" => "Skupina již existuje",
"Unable to add group" => "Nelze přidat skupinu",
"Files decrypted successfully" => "Soubory úspěšně dešifrovány",
"Couldn't decrypt your files, please check your owncloud.log or ask your administrator" => "Nebylo možno dešifrovat soubory, zkontroluje prosím owncloud.log nebo kontaktujte svého administrátora",
"Couldn't decrypt your files, check your password and try again" => "Nebylo možno dešifrovat soubory, zkontrolujte své heslo a zkuste znovu",
"Encryption keys deleted permanently" => "Šifrovací  klíče trvale smazány",
"Couldn't permanently delete your encryption keys, please check your owncloud.log or ask your administrator" => "Nebylo možno trvale smazat vaše šifrovací klíče, zkontrolujte prosím owncloud.log nebo kontaktujte svého administrátora",
"Couldn't remove app." => "Nepodařilo se odstranit aplikaci.",
"Email saved" => "E-mail uložen",
"Invalid email" => "Neplatný e-mail",
"Unable to delete group" => "Nelze smazat skupinu",
"Unable to delete user" => "Nelze smazat uživatele",
"Backups restored successfully" => "Zálohy úspěšně obnoveny",
"Couldn't restore your encryption keys, please check your owncloud.log or ask your administrator" => "Nebylo možno obnovit vaše šifrovací klíče, zkontrolujte prosím owncloud.log nebo kontaktujte svého administrátora",
"Language changed" => "Jazyk byl změněn",
"Invalid request" => "Neplatný požadavek",
"Admins can't remove themself from the admin group" => "Správci se nemohou odebrat sami ze skupiny správců",
"Unable to add user to group %s" => "Nelze přidat uživatele do skupiny %s",
"Unable to remove user from group %s" => "Nelze odebrat uživatele ze skupiny %s",
"Couldn't update app." => "Nelze aktualizovat aplikaci.",
"Wrong password" => "Nesprávné heslo",
"No user supplied" => "Nebyl uveden uživatel",
"Please provide an admin recovery password, otherwise all user data will be lost" => "Zadejte prosím administrátorské heslo pro obnovu, jinak budou všechna data ztracena",
"Wrong admin recovery password. Please check the password and try again." => "Chybné administrátorské heslo pro obnovu. Překontrolujte správnost hesla a zkuste to znovu.",
"Back-end doesn't support password change, but the users encryption key was successfully updated." => "Úložiště nepodporuje změnu hesla, ale šifrovací klíč uživatelů byl úspěšně změněn.",
"Unable to change password" => "Změna hesla se nezdařila",
"Sending..." => "Odesílání...",
"User Documentation" => "Uživatelská dokumentace",
"Admin Documentation" => "Dokumentace pro administrátory",
"Update to {appversion}" => "Aktualizovat na {appversion}",
"Uninstall App" => "Odinstalovat aplikaci",
"Disable" => "Zakázat",
"Enable" => "Povolit",
"Please wait...." => "Čekejte prosím...",
"Error while disabling app" => "Chyba při zakazování aplikace",
"Error while enabling app" => "Chyba při povolování aplikace",
"Updating...." => "Aktualizuji...",
"Error while updating app" => "Chyba při aktualizaci aplikace",
"Error" => "Chyba",
"Update" => "Aktualizovat",
"Updated" => "Aktualizováno",
"Uninstalling ...." => "Probíhá odinstalace ...",
"Error while uninstalling app" => "Chyba při odinstalaci aplikace",
"Uninstall" => "Odinstalovat",
"Select a profile picture" => "Vyberte profilový obrázek",
"Very weak password" => "Velmi slabé heslo",
"Weak password" => "Slabé heslo",
"So-so password" => "Středně silné heslo",
"Good password" => "Dobré heslo",
"Strong password" => "Silné heslo",
"Decrypting files... Please wait, this can take some time." => "Probíhá dešifrování souborů... Čekejte prosím, tato operace může trvat nějakou dobu.",
"Delete encryption keys permanently." => "Trvale smazat šifrovací klíče",
"Restore encryption keys." => "Obnovit šifrovací klíče",
"Unable to delete {objName}" => "Nelze smazat {objName}",
"Error creating group" => "Chyba při vytváření skupiny",
"A valid group name must be provided" => "Musíte zadat platný název skupiny",
"deleted {groupName}" => "smazána {groupName}",
"undo" => "vrátit zpět",
"Groups" => "Skupiny",
"Group Admin" => "Správa skupiny",
"Delete" => "Smazat",
"never" => "nikdy",
"deleted {userName}" => "smazán {userName}",
"add group" => "přidat skupinu",
"A valid username must be provided" => "Musíte zadat platné uživatelské jméno",
"Error creating user" => "Chyba při vytváření užiatele",
"A valid password must be provided" => "Musíte zadat platné heslo",
"Warning: Home directory for user \"{user}\" already exists" => "Varování: Osobní složka uživatele \"{user}\" již existuje.",
"__language_name__" => "Česky",
"Everything (fatal issues, errors, warnings, info, debug)" => "Vše (fatální problémy, chyby, varování, informační, ladící)",
"Info, warnings, errors and fatal issues" => "Informace, varování, chyby a fatální problémy",
"Warnings, errors and fatal issues" => "Varování, chyby a fatální problémy",
"Errors and fatal issues" => "Chyby a fatální problémy",
"Fatal issues only" => "Pouze fatální problémy",
"None" => "Žádné",
"Login" => "Přihlásit",
"Plain" => "Čistý text",
"NT LAN Manager" => "Správce NT LAN",
"SSL" => "SSL",
"TLS" => "TLS",
"Security Warning" => "Bezpečnostní upozornění",
"You are accessing %s via HTTP. We strongly suggest you configure your server to require using HTTPS instead." => "Přistupujete na %s protokolem HTTP. Důrazně doporučujeme nakonfigurovat server pro použití HTTPS.",
"Your data directory and your files are probably accessible from the internet. The .htaccess file is not working. We strongly suggest that you configure your webserver in a way that the data directory is no longer accessible or you move the data directory outside the webserver document root." => "Váš datový adresář i vaše soubory jsou pravděpodobně přístupné z internetu. Soubor .htaccess nefunguje. Důrazně doporučujeme nakonfigurovat webový server tak, aby datový adresář nebyl nadále přístupný, nebo přesunout datový adresář mimo prostor zpřístupňovaný webovým serverem.",
"Setup Warning" => "Upozornění nastavení",
"Your web server is not yet properly setup to allow files synchronization because the WebDAV interface seems to be broken." => "Váš webový server není správně nastaven pro umožnění synchronizace, protože rozhraní WebDAV se zdá nefunkční.",
"Please double check the <a href=\"%s\">installation guides</a>." => "Zkontrolujte prosím znovu <a href=\"%s\">instalační příručku</a>.",
"PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." => "PHP je patrně nastaveno tak, aby odstraňovalo vnitřní části dokumentů. Toto bude mít za následek množsví nedostupných hlavních aplikací.",
"This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." => "Toto je pravděpodobně způsobeno aplikacemi pro urychlení načítání jako jsou Zend OPcache nebo eAccelerator.",
"Database Performance Info" => "Informace o výkonu databáze",
"SQLite is used as database. For larger installations we recommend to change this. To migrate to another database use the command line tool: 'occ db:convert-type'" => "Je použita databáze SQLite. Pro větší instalace doporučujeme toto změnit. Pro migraci na jiný typ databáze lze použít příkaz: 'occ db:convert-type'",
"Module 'fileinfo' missing" => "Schází modul 'fileinfo'",
"The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." => "Schází PHP modul 'fileinfo'. Doporučujeme jej povolit pro nejlepší výsledky detekce typů MIME.",
"Your PHP version is outdated" => "Vaše verze PHP je zastaralá",
"Your PHP version is outdated. We strongly recommend to update to 5.3.8 or newer because older versions are known to be broken. It is possible that this installation is not working correctly." => "Vámi používaná verze PHP je zastaralá. Důrazně doporučujeme aktualizovat na verzi 5.3.8 nebo novější, protože starší verze obsahují chyby. Je možné, že tato instalace nebude fungovat správně.",
"Locale not working" => "Lokalizace nefunguje",
"System locale can not be set to a one which supports UTF-8." => "Není možné nastavit znakovou sadu, která podporuje UTF-8.",
"This means that there might be problems with certain characters in file names." => "To znamená, že se mohou vyskytnout problémy s určitými znaky v názvech souborů.",
"We strongly suggest to install the required packages on your system to support one of the following locales: %s." => "Důrazně doporučujeme nainstalovat do vašeho systém balíčky nutné pro podporu některé z následujících znakových sad: %s.",
"Internet connection not working" => "Připojení k internetu nefunguje",
"This server has no working internet connection. This means that some of the features like mounting of external storage, notifications about updates or installation of 3rd party apps don´t work. Accessing files from remote and sending of notification emails might also not work. We suggest to enable internet connection for this server if you want to have all features." => "Server nemá funkční připojení k internetu. Některé moduly jako např. externí úložiště, oznámení o dostupných aktualizacích nebo instalace aplikací třetích stran nebudou fungovat. Přístup k souborům z jiných míst a odesílání oznamovacích e-mailů také nemusí fungovat. Pokud si přejete využívat všech vlastností ownCloud, doporučujeme povolit připojení k internetu tomuto serveru.",
"Cron" => "Cron",
"Last cron was executed at %s." => "Poslední cron byl spuštěn v %s",
"Last cron was executed at %s. This is more than an hour ago, something seems wrong." => "Poslední cron byl spuštěn v %s. To je více než před hodinou. Vypadá to, že není něco v pořádku.",
"Cron was not executed yet!" => "Cron ještě nebyl spuštěn!",
"Execute one task with each page loaded" => "Spustit jednu úlohu s každým načtením stránky",
"cron.php is registered at a webcron service to call cron.php every 15 minutes over http." => "cron.php je registrován u služby webcron, aby volal cron.php jednou za 15 minut přes http.",
"Use system's cron service to call the cron.php file every 15 minutes." => "Použít systémovou službu cron pro volání cron.php každých 15 minut.",
"Sharing" => "Sdílení",
"Allow apps to use the Share API" => "Povolit aplikacím používat API sdílení",
"Allow users to share via link" => "Povolit uživatelům sdílení pomocí odkazů",
"Enforce password protection" => "Vynutit ochranu heslem",
"Allow public uploads" => "Povolit veřejné nahrávání souborů",
"Set default expiration date" => "Nastavit výchozí datum vypršení platnosti",
"Expire after " => "Vyprší po",
"days" => "dnech",
"Enforce expiration date" => "Vynutit datum vypršení",
"Allow resharing" => "Povolit znovu-sdílení",
"Restrict users to only share with users in their groups" => "Povolit sdílení pouze mezi uživateli v rámci skupiny",
"Allow users to send mail notification for shared files" => "Povolit uživatelům odesílat e-mailová upozornění pro sdílené soubory",
"Exclude groups from sharing" => "Vyjmout skupiny ze sdílení",
"These groups will still be able to receive shares, but not to initiate them." => "Těmto skupinám bude stále možno sdílet, nemohou ale sami sdílet ostatním.",
"Security" => "Zabezpečení",
"Enforce HTTPS" => "Vynutit HTTPS",
"Forces the clients to connect to %s via an encrypted connection." => "Vynutí připojování klientů k %s šifrovaným spojením.",
"Please connect to your %s via HTTPS to enable or disable the SSL enforcement." => "Připojte se k %s skrze HTTPS pro povolení nebo zakázání vynucování SSL.",
"Email Server" => "E-mailový server",
"This is used for sending out notifications." => "Toto se používá pro odesílání upozornění.",
"From address" => "Adresa odesílatele",
"mail" => "e-mail",
"Authentication required" => "Vyžadováno ověření",
"Server address" => "Adresa serveru",
"Port" => "Port",
"Credentials" => "Přihlašovací údaje",
"SMTP Username" => "SMTP uživatelské jméno ",
"SMTP Password" => "SMTP heslo",
"Test email settings" => "Otestovat nastavení e-mailu",
"Send email" => "Odeslat e-mail",
"Log" => "Záznam",
"Log level" => "Úroveň zaznamenávání",
"More" => "Více",
"Less" => "Méně",
"Version" => "Verze",
"Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." => "Vyvinuto <a href=\"http://ownCloud.org/contact\" target=\"_blank\">komunitou ownCloud</a>, <a href=\"https://github.com/owncloud\" target=\"_blank\">zdrojový kód</a> je licencován pod <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>.",
"Add your App" => "Přidat Vaši aplikaci",
"More Apps" => "Více aplikací",
"Select an App" => "Vyberte aplikaci",
"Documentation:" => "Dokumentace:",
"See application page at apps.owncloud.com" => "Více na stránce s aplikacemi na apps.owncloud.com",
"See application website" => "Prohlédněte si webovou stránku aplikace",
"<span class=\"licence\"></span>-licensed by <span class=\"author\"></span>" => "<span class=\"licence\"></span>-licencováno <span class=\"author\"></span>",
"Enable only for specific groups" => "Povolit pouze pro vybrané skupiny",
"All" => "Vše",
"Administrator Documentation" => "Dokumentace správce",
"Online Documentation" => "Online dokumentace",
"Forum" => "Fórum",
"Bugtracker" => "Bugtracker",
"Commercial Support" => "Placená podpora",
"Get the apps to sync your files" => "Získat aplikace pro synchronizaci vašich souborů",
"Show First Run Wizard again" => "Znovu zobrazit průvodce prvním spuštěním",
"You have used <strong>%s</strong> of the available <strong>%s</strong>" => "Používáte <strong>%s</strong> z <strong>%s</strong> dostupných",
"Password" => "Heslo",
"Your password was changed" => "Vaše heslo bylo změněno",
"Unable to change your password" => "Změna vašeho hesla se nezdařila",
"Current password" => "Současné heslo",
"New password" => "Nové heslo",
"Change password" => "Změnit heslo",
"Full Name" => "Celé jméno",
"Email" => "E-mail",
"Your email address" => "Vaše e-mailová adresa",
"Fill in an email address to enable password recovery and receive notifications" => "Zadejte e-mailovou adresu pro umožnění obnovy zapomenutého hesla a pro přijímání upozornění",
"Profile picture" => "Profilový obrázek",
"Upload new" => "Nahrát nový",
"Select new from Files" => "Vyberte nový ze souborů",
"Remove image" => "Odebrat obrázek",
"Either png or jpg. Ideally square but you will be able to crop it." => "png nebo jpg, nejlépe čtvercový, ale budete mít možnost jej oříznout.",
"Your avatar is provided by your original account." => "Váš avatar je poskytován Vaším původním účtem.",
"Cancel" => "Zrušit",
"Choose as profile image" => "Vybrat jako profilový obrázek",
"Language" => "Jazyk",
"Help translate" => "Pomoci s překladem",
"The encryption app is no longer enabled, please decrypt all your files" => "Šifrovací aplikace již není spuštěna, dešifrujte prosím všechny své soubory",
"Log-in password" => "Přihlašovací heslo",
"Decrypt all Files" => "Odšifrovat všechny soubory",
"Your encryption keys are moved to a backup location. If something went wrong you can restore the keys. Only delete them permanently if you are sure that all files are decrypted correctly." => "Vaše šifrovací klíče byly zálohovány. Pokud se něco pokazilo, dají se znovu obnovit. Smažte je trvale pouze pokud jste jisti, že jsou všechny vaše soubory bezchybně dešifrovány.",
"Restore Encryption Keys" => "Obnovit šifrovací klíče",
"Delete Encryption Keys" => "Smazat šifrovací klíče",
"Login Name" => "Přihlašovací jméno",
"Create" => "Vytvořit",
"Admin Recovery Password" => "Heslo obnovy správce",
"Enter the recovery password in order to recover the users files during password change" => "Zadejte heslo obnovy pro obnovení souborů uživatele při změně hesla",
"Search Users and Groups" => "Prohledat uživatele a skupiny",
"Add Group" => "Přidat skupinu",
"Group" => "Skupina",
"Everyone" => "Všichni",
"Admins" => "Administrátoři",
"Default Quota" => "Výchozí kvóta",
"Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" => "Zvolte prosím kvótu pro úložiště (např. \"512 MB\" nebo \"12 GB\")",
"Unlimited" => "Neomezeně",
"Other" => "Jiný",
"Username" => "Uživatelské jméno",
"Quota" => "Kvóta",
"Storage Location" => "Umístění úložiště",
"Last Login" => "Poslední přihlášení",
"change full name" => "změnit celé jméno",
"set new password" => "nastavit nové heslo",
"Default" => "Výchozí",
"If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwritewebroot\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" => "Instalace mimo kořenový adresář domény a používání systémového příkazu cron může způsobit problém s generováním správné URL. Pro zabránění těmto chybám nastavte prosím správnou cestu ve svém config.php souboru v hodnotě \"overwritewebroot\" (Doporučujeme: \"%s\")",
"URL generation in notification emails" => "Generování adresy URL v oznamovacích e-mailech",
"Connectivity Checks" => "Ověřování připojení",
"No problems found" => "Nebyly nalezeny žádné problémy",
);
$PLURAL_FORMS = "nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;";
